@@ -4,7 +4,6 @@ from plone.tiles.tile import PersistentTile
 
 
 class DictDataWrapper(object):
-
     def __init__(self, data):
         self.data = data
 
@@ -16,19 +15,15 @@ class DictDataWrapper(object):
 
 
 class BaseFilterTile(PersistentTile):
-
     def available(self):
         # do not render when page is ajax loaded
-        return 'ajax_load' not in self.top_request
+        return "ajax_load" not in self.top_request
 
     @property
     def edit_url(self):
-        if not api.user.has_permission(
-            'cmf.ModifyPortalContent',
-            obj=self.context
-        ):
+        if not api.user.has_permission("cmf.ModifyPortalContent", obj=self.context):
             return None
-        return self.url.replace('@@', '@@edit-tile/')
+        return self.url.replace("@@", "@@edit-tile/")
 
     @property
     def settings(self):
