@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from collective.collectionfilter.baseviews import BaseSortOnView
-from collective.collectionfilter.interfaces import ICollectionFilterResultListSort  # noqa
+from collective.collectionfilter.interfaces import (  # noqa
+    ICollectionFilterResultListSort,
+)
 from collective.collectionfilter.tiles import BaseFilterTile
 from plone.supermodel.model import Schema
 from zope.interface import implementer
